==> importer-local-0.0.22.tar.gz: importer-local-0.0.22/circles_importer/importer.py <==
from circles_local_database_python.database import database
from dotenv import load_dotenv
from logger_local.LoggerLocal import logger_local
from functools import wraps
load_dotenv()
logger_local.setWriteToSql(True)
object_init = {
    'component_id': 114
}
logger_local.init(object=object_init)


def log_function_execution(func):
    @wraps(func)
    def wrapper(*args, **kwargs):
        object1 = {
            'args': str(args),
            'kawargs': str(kwargs),
        }
        logger_local.start(object=object1)
        result = func(*args, **kwargs)  # Execute the function
        object2 = {
            'result': result,
        }
        logger_local.end(object=object2)
        return result
    return wrapper


class Importer:
    def __init__(self):
        pass

    @log_function_execution
    def insert_record_data_source(self, data_source_id: int, location_id: int, entity_type_id: int, entity_id: int, url: str, user_id: int):
        object1 = {
            'source_id': data_source_id,
            'entity_type_name': entity_type_id,
            'entity_id': entity_id,
            'url': url,
            'location_id': location_id,
            'user_id': user_id
        }
        logger_local.start(object=object1)
        try:
            database_conn = database()
            db = database_conn.connect_to_database()
            cursor = db.cursor()

            cursor.execute(
                "SELECT country_id FROM location.country_table WHERE name = '{}'".format(location_id))
            country_id = cursor.fetchone()

            query_importer = "INSERT INTO importer.importer_table(`source_id`,`country_id`,`entity_type_id`,`entity_id`,`url`,`created_user_id`,`updated_user_id`)" \
                " VALUES (%s, %s, %s, %s, %s, %s, %s)"

            cursor.execute(
                query_importer, (data_source_id, country_id[0], entity_type_id, entity_id, url, user_id, user_id))

            db.commit()
            db.close()
            logger_local.info("add importer record succeeded")
        except Exception as e:
            logger_local.exception(object=e)
        logger_local.end(object={})


if __name__ == "__main__":
    pass

==> importer-local-0.0.23.tar.gz: importer-local-0.0.23/circles_importer/importer.py <==
from circles_local_database_python.database import database
from dotenv import load_dotenv
from logger_local.LoggerLocal import logger_local

load_dotenv()
object_init = {
    'component_id': 114
}
logger_local.init(object=object_init)



class Importer:
    def __init__(self):
        pass

    def insert_record_data_source(self, data_source_id: int, location_id: int, entity_type_id: int, entity_id: int, url: str, user_id: int):
        object1 = {
            'source_id': data_source_id,
            'entity_type_name': entity_type_id,
            'entity_id': entity_id,
            'url': url,
            'location_id': location_id,
            'user_id': user_id
        }
        logger_local.start(object=object1)
        try:
            database_conn = database()
            db = database_conn.connect_to_database()
            cursor = db.cursor()

            cursor.execute(
                "SELECT country_id FROM location.country_table WHERE name = '{}'".format(location_id))
            country_id = cursor.fetchone()

            query_importer = "INSERT INTO importer.importer_table(`source_id`,`country_id`,`entity_type_id`,`entity_id`,`url`,`created_user_id`,`updated_user_id`)" \
                " VALUES (%s, %s, %s, %s, %s, %s, %s)"

            cursor.execute(
                query_importer, (data_source_id, country_id[0], entity_type_id, entity_id, url, user_id, user_id))

            db.commit()
            db.close()
            logger_local.info("add importer record succeeded")#view logger_local.end at the end of the function
        except Exception as e:
            logger_local.exception(object=e)
        logger_local.end(object={})


if __name__ == "__main__":
    pass
